From 804d7a1aa6fd33fbe405698d90d02121423e540c Mon Sep 17 00:00:00 2001
From: Diego Biurrun <diego@biurrun.de>
Date: Thu, 9 Aug 2012 03:06:01 +0200
Subject: [PATCH] doxygen: Fix function parameter names to match the code

---
 libavcodec/vp8.c              | 2 +-
 libavfilter/buffersink.h      | 6 +++---
 libavresample/audio_convert.h | 2 +-
 libavresample/audio_mix.h     | 2 +-
 libavutil/xtea.h              | 4 ++--
 5 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/libavcodec/vp8.c b/libavcodec/vp8.c
index 3f88d78306f..e50d7c99b70 100644
--- a/libavcodec/vp8.c
+++ b/libavcodec/vp8.c
@@ -751,7 +751,7 @@ void decode_mb_mode(VP8Context *s, VP8Macroblock *mb, int mb_x, int mb_y,
 
 #ifndef decode_block_coeffs_internal
 /**
- * @param c arithmetic bitstream reader context
+ * @param r arithmetic bitstream reader context
  * @param block destination for block coefficients
  * @param probs probabilities to use when reading trees from the bitstream
  * @param i initial coeff index, 0 unless a separate DC block is coded
diff --git a/libavresample/audio_convert.h b/libavresample/audio_convert.h
index 92277636288..eefffbb12cd 100644
--- a/libavresample/audio_convert.h
+++ b/libavresample/audio_convert.h
@@ -42,7 +42,7 @@ typedef struct AudioConvert AudioConvert;
  * @param in_fmt         input sample format
  * @param channels       number of channels, or 0 for any number of channels
  * @param ptr_align      buffer pointer alignment, in bytes
- * @param sample_align   buffer size alignment, in samples
+ * @param samples_align  buffer size alignment, in samples
  * @param descr          function type description (e.g. "C" or "SSE")
  * @param conv           conversion function pointer
  */
diff --git a/libavresample/audio_mix.h b/libavresample/audio_mix.h
index 61db33047d7..2199fffe0ec 100644
--- a/libavresample/audio_mix.h
+++ b/libavresample/audio_mix.h
@@ -69,7 +69,7 @@ typedef struct AudioMix {
  * @param in_channels    number of input channels, or 0 for any number of channels
  * @param out_channels   number of output channels, or 0 for any number of channels
  * @param ptr_align      buffer pointer alignment, in bytes
- * @param sample_align   buffer size alignment, in samples
+ * @param samples_align  buffer size alignment, in samples
  * @param descr          function type description (e.g. "C" or "SSE")
  * @param mix_func       mixing function pointer
  */
diff --git a/libavutil/xtea.h b/libavutil/xtea.h
index cf305c6632a..7d2b07bbc73 100644
--- a/libavutil/xtea.h
+++ b/libavutil/xtea.h
@@ -36,7 +36,7 @@ typedef struct AVXTEA {
 /**
  * Initialize an AVXTEA context.
  *
- * @param x an AVXTEA context
+ * @param ctx an AVXTEA context
  * @param key a key of 16 bytes used for encryption/decryption
  */
 void av_xtea_init(struct AVXTEA *ctx, const uint8_t key[16]);
@@ -44,7 +44,7 @@ void av_xtea_init(struct AVXTEA *ctx, const uint8_t key[16]);
 /**
  * Encrypt or decrypt a buffer using a previously initialized context.
  *
- * @param x an AVXTEA context
+ * @param ctx an AVXTEA context
  * @param dst destination array, can be equal to src
  * @param src source array, can be equal to dst
  * @param count number of 8 byte blocks
diff --git a/libavfilter/buffersink.h b/libavfilter/buffersink.h
index 8f94a9c94d5..e358ac34129 100644
--- a/libavfilter/buffersink.h
+++ b/libavfilter/buffersink.h
@@ -29,7 +29,7 @@
 /**
  * Get a buffer with filtered data from sink and put it in buf.
  *
  * @param sink pointer to a context of a buffersink or abuffersink AVFilter.
  * @param buf pointer to the buffer will be written here if buf is non-NULL. buf
  *            must be freed by the caller using avfilter_unref_buffer().
  *            Buf may also be NULL to query whether a buffer is ready to be
@@ -38,14 +38,14 @@
  * @return >= 0 in case of success, a negative AVERROR code in case of
  *         failure.
  */
-int av_buffersink_read(AVFilterContext *sink, AVFilterBufferRef **buf);
+int av_buffersink_read(AVFilterContext *ctx, AVFilterBufferRef **buf);
 
 /**
  * Same as av_buffersink_read, but with the ability to specify the number of
  * samples read. This function is less efficient than av_buffersink_read(),
  * because it copies the data around.
  *
  * @param sink pointer to a context of the abuffersink AVFilter.
  * @param buf pointer to the buffer will be written here if buf is non-NULL. buf
  *            must be freed by the caller using avfilter_unref_buffer(). buf
  *            will contain exactly nb_samples audio samples, except at the end
@@ -29,7 +29,7 @@
  * Get a buffer with filtered data from sink and put it in buf.
  *
- * @param sink pointer to a context of a buffersink or abuffersink AVFilter.
+ * @param ctx pointer to a context of a buffersink or abuffersink AVFilter.
  * @param buf pointer to the buffer will be written here if buf is non-NULL. buf
  *            must be freed by the caller using avfilter_unref_buffer().
@@ -38,14 +38,14 @@
  * because it copies the data around.
  *
- * @param sink pointer to a context of the abuffersink AVFilter.
+ * @param ctx pointer to a context of the abuffersink AVFilter.
  * @param buf pointer to the buffer will be written here if buf is non-NULL. buf
  *            must be freed by the caller using avfilter_unref_buffer(). buf
-- 
GitLab